#ifndef __FLASH_H
#define __FLASH_H


/* FLASH OISR Flags                                                                                         */
#define FLASH_FLAG_ORFF               0x00000001   /* Operation Finished Flag                        */
#define FLASH_FLAG_ITADF              0x00000002   /* Invalid Target Address Flag                    */
#define FLASH_FLAG_OBEF               0x00000004   /* Option Byte Check Sum Error Flag               */
#define FLASH_FLAG_IOCMF              0x00000008   /* Invalid Operation Command Flag                 */
#define FLASH_FLAG_OREF               0x00000010   /* Operation Error Flag                           */
#define FLASH_FLAG_RORFF              0x00010000   /* Raw Operation Finished Flag                    */
#define FLASH_FLAG_PPERF              0x00020000   /* Page Erase/Program Protected Error Flag        */

/* FLASH OIER                                                                                        */
#define FLASH_INT_ORFIE               0x00000001   /* Flash Operation Finished Interrupt Enable      */
#define FLASH_INT_ITADIE              0x00000002   /* Invalid Target Address Interrupt Enable        */
#define FLASH_INT_OBEIE               0x00000004   /* Option Byte Check Sum Error Interrupt Enable   */
#define FLASH_INT_IOCMIE              0x00000008   /* Invalid Operation Command Interrupt Enable     */
#define FLASH_INT_OREIE               0x00000010   /* Operation Error Interrupt Enable               */
#define FLASH_INT_ALL                 0x0000001F   /* Flash all Interrupt Enable                     */

/* FLASH OCMR                                                                                        */
#define FLASH_CMD_STANDBY             0x00000000
#define FLASH_CMD_PROGRAM             0x00000004
#define FLASH_CMD_PAGEERASE           0x00000008
#define FLASH_CMD_MASSERASE           0x0000000A

/* FLASH OPCR                                                                                             */
#define FLASH_IDLE                    (0x6<<1)
#define FLASH_READY                   (0xE<<1)
#define FLASH_SEND_MAIN               (0xA<<1)

/* FLASH CFCR                                                                                             */
#define CFCR_WAIT_MASK                0xFFFFFFF0
#define CFCR_PFBE_MASK                0xFFFFFFEF
#define CFCR_IPSE_MASK                0xFFFFFFBF  

#endif
